@@ -6,8 +6,8 @@ warnings.filterwarnings("ignore", category=UserWarning)
 
 class Config:
     def __init__(self):
-        self.xlmr_model_name = 'xlm-roberta-base'
-        self.xlmr_dropout = 0.3
+        self.embedding_name = 'xlm-roberta-base'
+        self.embedding_dropout = 0.3
         self.hidden_num = 300
         self.linear_dropout = 0.1
         self.linear_bias = 1
